# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/dag_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cyber.proto import component_conf_pb2 as cyber_dot_proto_dot_component__conf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/dag_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x63yber/proto/dag_conf.proto\x12\x12\x61pollo.cyber.proto\x1a cyber/proto/component_conf.proto\"X\n\rComponentInfo\x12\x12\n\nclass_name\x18\x01 \x01(\t\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32#.apollo.cyber.proto.ComponentConfig\"b\n\x12TimerComponentInfo\x12\x12\n\nclass_name\x18\x01 \x01(\t\x12\x38\n\x06\x63onfig\x18\x02 \x01(\x0b\x32(.apollo.cyber.proto.TimerComponentConfig\"\x9f\x01\n\x0cModuleConfig\x12\x16\n\x0emodule_library\x18\x01 \x01(\t\x12\x35\n\ncomponents\x18\x02 \x03(\x0b\x32!.apollo.cyber.proto.ComponentInfo\x12@\n\x10timer_components\x18\x03 \x03(\x0b\x32&.apollo.cyber.proto.TimerComponentInfo\"D\n\tDagConfig\x12\x37\n\rmodule_config\x18\x01 \x03(\x0b\x32 .apollo.cyber.proto.ModuleConfig'
  ,
  dependencies=[cyber_dot_proto_dot_component__conf__pb2.DESCRIPTOR,])




_COMPONENTINFO = _descriptor.Descriptor(
  name='ComponentInfo',
  full_name='apollo.cyber.proto.ComponentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_name', full_name='apollo.cyber.proto.ComponentInfo.class_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='apollo.cyber.proto.ComponentInfo.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=172,
)


_TIMERCOMPONENTINFO = _descriptor.Descriptor(
  name='TimerComponentInfo',
  full_name='apollo.cyber.proto.TimerComponentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_name', full_name='apollo.cyber.proto.TimerComponentInfo.class_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='apollo.cyber.proto.TimerComponentInfo.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=272,
)


_MODULECONFIG = _descriptor.Descriptor(
  name='ModuleConfig',
  full_name='apollo.cyber.proto.ModuleConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='module_library', full_name='apollo.cyber.proto.ModuleConfig.module_library', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='components', full_name='apollo.cyber.proto.ModuleConfig.components', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timer_components', full_name='apollo.cyber.proto.ModuleConfig.timer_components', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=434,
)


_DAGCONFIG = _descriptor.Descriptor(
  name='DagConfig',
  full_name='apollo.cyber.proto.DagConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='module_config', full_name='apollo.cyber.proto.DagConfig.module_config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=504,
)

_COMPONENTINFO.fields_by_name['config'].message_type = cyber_dot_proto_dot_component__conf__pb2._COMPONENTCONFIG
_TIMERCOMPONENTINFO.fields_by_name['config'].message_type = cyber_dot_proto_dot_component__conf__pb2._TIMERCOMPONENTCONFIG
_MODULECONFIG.fields_by_name['components'].message_type = _COMPONENTINFO
_MODULECONFIG.fields_by_name['timer_components'].message_type = _TIMERCOMPONENTINFO
_DAGCONFIG.fields_by_name['module_config'].message_type = _MODULECONFIG
DESCRIPTOR.message_types_by_name['ComponentInfo'] = _COMPONENTINFO
DESCRIPTOR.message_types_by_name['TimerComponentInfo'] = _TIMERCOMPONENTINFO
DESCRIPTOR.message_types_by_name['ModuleConfig'] = _MODULECONFIG
DESCRIPTOR.message_types_by_name['DagConfig'] = _DAGCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ComponentInfo = _reflection.GeneratedProtocolMessageType('ComponentInfo', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTINFO,
  '__module__' : 'cyber.proto.dag_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ComponentInfo)
  })
_sym_db.RegisterMessage(ComponentInfo)

TimerComponentInfo = _reflection.GeneratedProtocolMessageType('TimerComponentInfo', (_message.Message,), {
  'DESCRIPTOR' : _TIMERCOMPONENTINFO,
  '__module__' : 'cyber.proto.dag_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.TimerComponentInfo)
  })
_sym_db.RegisterMessage(TimerComponentInfo)

ModuleConfig = _reflection.GeneratedProtocolMessageType('ModuleConfig', (_message.Message,), {
  'DESCRIPTOR' : _MODULECONFIG,
  '__module__' : 'cyber.proto.dag_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ModuleConfig)
  })
_sym_db.RegisterMessage(ModuleConfig)

DagConfig = _reflection.GeneratedProtocolMessageType('DagConfig', (_message.Message,), {
  'DESCRIPTOR' : _DAGCONFIG,
  '__module__' : 'cyber.proto.dag_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.DagConfig)
  })
_sym_db.RegisterMessage(DagConfig)


# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python

# Copyright 2022 daohu527 <daohu527@gmail.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import cv2
import time
import logging
import numpy as np

from record_msg import pypcd

from modules.drivers.proto import sensor_image_pb2, pointcloud_pb2
from modules.localization.proto import localization_pb2
from modules.transform.proto import transform_pb2

class Builder(object):
  def __init__(self) -> None:
    self._sequence_num = 0

  def _build_header(self, header,
      t=None, module_name=None, version=None, frame_id=None):
    header.sequence_num = self._sequence_num
    if t:
      header.timestamp_sec = t
      # todo(zero): no need to add?
      # header.camera_timestamp = int(t * 1e9)
      # header.lidar_timestamp = int(t * 1e9)
    if module_name:
      header.module_name = module_name
    if version:
      header.version = version
    if frame_id:
      header.frame_id = frame_id


class TransformBuilder(Builder):
  def __init__(self) -> None:
    super().__init__()

  def build(self, frame_id, child_frame_id, translation, rotation, t):
    pb_transformstampeds = transform_pb2.TransformStampeds()
    pb_transformstamped = pb_transformstampeds.transforms.add()
    if t is None:
      t = time.time()

    self._build_header(pb_transformstamped.header, t=t, frame_id=frame_id)
    pb_transformstamped.child_frame_id = child_frame_id
    pb_transformstamped.transform.translation.x = translation[0]
    pb_transformstamped.transform.translation.y = translation[1]
    pb_transformstamped.transform.translation.z = translation[2]

    pb_transformstamped.transform.rotation.qw = rotation[0]
    pb_transformstamped.transform.rotation.qx = rotation[1]
    pb_transformstamped.transform.rotation.qy = rotation[2]
    pb_transformstamped.transform.rotation.qz = rotation[3]

    self._sequence_num += 1
    return pb_transformstampeds


class LocalizationBuilder(Builder):
  def __init__(self) -> None:
    super().__init__()

  def build(self, translation, rotation, t):
    pb_localization = localization_pb2.LocalizationEstimate()
    if t is None:
      t = time.time()

    self._build_header(pb_localization.header, t=t, module_name='localization')
    pb_localization.pose.position.x = translation[0]
    pb_localization.pose.position.y = translation[1]
    pb_localization.pose.position.z = translation[2]

    pb_localization.pose.orientation.qw = rotation[0]
    pb_localization.pose.orientation.qx = rotation[1]
    pb_localization.pose.orientation.qy = rotation[2]
    pb_localization.pose.orientation.qz = rotation[3]

    # todo(zero): need to complete
    # pb_localization.pose.linear_velocity
    # pb_localization.pose.linear_acceleration
    # pb_localization.pose.angular_velocity
    # pb_localization.pose.heading

    pb_localization.measurement_time = t
    self._sequence_num += 1
    return pb_localization


class ImageBuilder(Builder):
  def __init__(self) -> None:
    super().__init__()

  def _to_flag(self, encoding):
    if encoding == 'rgb8' or encoding == 'bgr8':
      return cv2.IMREAD_COLOR
    elif encoding == 'gray' or encoding == 'y':
      return cv2.IMREAD_GRAYSCALE
    else:
      print('Unsupported image encoding type: %s.' % encoding)
      return None

  def build(self, file_name, frame_id, encoding, t=None):
    pb_image = sensor_image_pb2.Image()
    flag = self._to_flag(encoding)
    if flag is None:
      return

    if t is None:
      t = time.time()

    self._build_header(pb_image.header, frame_id=frame_id)
    pb_image.frame_id = frame_id
    pb_image.measurement_time = t
    pb_image.encoding = encoding

    img = cv2.imread(file_name, flag)

    pb_image.height, pb_image.width, channels = img.shape
    pb_image.step = pb_image.width * channels

    # todo(zero): which one is right?
    # if flag == cv2.IMREAD_COLOR:
    #   pb_image.step = pb_image.width * 3
    # elif flag == cv2.IMREAD_GRAYSCALE:
    #   pb_image.step = pb_image.width
    # else:
    #   return

    pb_image.data = img.tostring()
    self._sequence_num += 1
    return pb_image


class PointCloudBuilder(Builder):
  def __init__(self) -> None:
    super().__init__()

  def build(self, file_name, frame_id, t=None):
    pb_point_cloud = pointcloud_pb2.PointCloud()

    if t is None:
      t = time.time()

    self._build_header(pb_point_cloud.header, t=t, frame_id=frame_id)
    pb_point_cloud.frame_id = frame_id
    # pb_point_cloud.is_dense = False
    pb_point_cloud.measurement_time = t

    point_cloud = pypcd.point_cloud_from_path(file_name)

    pb_point_cloud.width = point_cloud.width
    pb_point_cloud.height = point_cloud.height

    for data in point_cloud.pc_data:
      point = pb_point_cloud.point.add()
      point.x, point.y, point.z, point.intensity, timestamp = data
      point.timestamp = int(timestamp * 1e9)

    self._sequence_num += 1
    return pb_point_cloud

  def build_nuscenes(self, file_name, frame_id, t=None):
    pb_point_cloud = pointcloud_pb2.PointCloud()

    if t is None:
      t = time.time()

    self._build_header(pb_point_cloud.header, t=t, frame_id=frame_id)
    pb_point_cloud.frame_id = frame_id
    # pb_point_cloud.is_dense = False
    pb_point_cloud.measurement_time = t

    # Loads LIDAR data from binary numpy format.
    # Data is stored as (x, y, z, intensity, ring index).
    scan = np.fromfile(file_name, dtype=np.float32)
    logging.debug(scan[:100])

    points = scan.reshape((-1, 5))[:, :4]
    logging.debug("points: {},{}".format(np.shape(points), points.dtype))

    pb_point_cloud.width = len(points)
    pb_point_cloud.height = 1

    # Points shape is (length, 4)
    n0, _ = np.shape(points)
    for i in range(n0):
      point = pb_point_cloud.point.add()
      point.x, point.y, point.z, intensity = points[i]
      point.intensity = int(intensity)
    self._sequence_num += 1
    return pb_point_cloud



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/vehicle_parameter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.common.configs.proto import vehicle_config_pb2 as modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/vehicle_parameter.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,modules/canbus/proto/vehicle_parameter.proto\x12\rapollo.canbus\x1a\"modules/canbus/proto/chassis.proto\x1a\x31modules/common/configs/proto/vehicle_config.proto\"\xb3\x01\n\x10VehicleParameter\x12*\n\x05\x62rand\x18\x01 \x01(\x0e\x32\x1b.apollo.common.VehicleBrand\x12\x18\n\x10max_engine_pedal\x18\x02 \x01(\x01\x12\x1f\n\x17max_enable_fail_attempt\x18\x03 \x01(\x05\x12\x38\n\x0c\x64riving_mode\x18\x04 \x01(\x0e\x32\".apollo.canbus.Chassis.DrivingMode'
  ,
  dependencies=[modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2.DESCRIPTOR,])




_VEHICLEPARAMETER = _descriptor.Descriptor(
  name='VehicleParameter',
  full_name='apollo.canbus.VehicleParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brand', full_name='apollo.canbus.VehicleParameter.brand', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_engine_pedal', full_name='apollo.canbus.VehicleParameter.max_engine_pedal', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_enable_fail_attempt', full_name='apollo.canbus.VehicleParameter.max_enable_fail_attempt', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driving_mode', full_name='apollo.canbus.VehicleParameter.driving_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=330,
)

_VEHICLEPARAMETER.fields_by_name['brand'].enum_type = modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2._VEHICLEBRAND
_VEHICLEPARAMETER.fields_by_name['driving_mode'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_DRIVINGMODE
DESCRIPTOR.message_types_by_name['VehicleParameter'] = _VEHICLEPARAMETER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VehicleParameter = _reflection.GeneratedProtocolMessageType('VehicleParameter', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEPARAMETER,
  '__module__' : 'modules.canbus.proto.vehicle_parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.VehicleParameter)
  })
_sym_db.RegisterMessage(VehicleParameter)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/monitor_log/proto/monitor_log.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/monitor_log/proto/monitor_log.proto',
  package='apollo.common.monitor',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2modules/common/monitor_log/proto/monitor_log.proto\x12\x15\x61pollo.common.monitor\x1a!modules/common/proto/header.proto\"\xaf\x04\n\x12MonitorMessageItem\x12P\n\x06source\x18\x01 \x01(\x0e\x32\x37.apollo.common.monitor.MonitorMessageItem.MessageSource:\x07UNKNOWN\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12K\n\tlog_level\x18\x03 \x01(\x0e\x32\x32.apollo.common.monitor.MonitorMessageItem.LogLevel:\x04INFO\"\xb6\x02\n\rMessageSource\x12\x0b\n\x07UNKNOWN\x10\x01\x12\n\n\x06\x43\x41NBUS\x10\x02\x12\x0b\n\x07\x43ONTROL\x10\x03\x12\x0c\n\x08\x44\x45\x43ISION\x10\x04\x12\x10\n\x0cLOCALIZATION\x10\x05\x12\x0c\n\x08PLANNING\x10\x06\x12\x0e\n\nPREDICTION\x10\x07\x12\r\n\tSIMULATOR\x10\x08\x12\t\n\x05HWSYS\x10\t\x12\x0b\n\x07ROUTING\x10\n\x12\x0b\n\x07MONITOR\x10\x0b\x12\x07\n\x03HMI\x10\x0c\x12\x10\n\x0cRELATIVE_MAP\x10\r\x12\x08\n\x04GNSS\x10\x0e\x12\x0f\n\x0b\x43ONTI_RADAR\x10\x0f\x12\x11\n\rRACOBIT_RADAR\x10\x10\x12\x14\n\x10ULTRASONIC_RADAR\x10\x11\x12\x0c\n\x08MOBILEYE\x10\x12\x12\x0e\n\nDELPHI_ESR\x10\x13\x12\x10\n\x0cSTORYTELLING\x10\x14\"4\n\x08LogLevel\x12\x08\n\x04INFO\x10\x00\x12\x08\n\x04WARN\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\t\n\x05\x46\x41TAL\x10\x03\"p\n\x0eMonitorMessage\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x37\n\x04item\x18\x02 \x03(\x0b\x32).apollo.common.monitor.MonitorMessageItem'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])



_MONITORMESSAGEITEM_MESSAGESOURCE = _descriptor.EnumDescriptor(
  name='MessageSource',
  full_name='apollo.common.monitor.MonitorMessageItem.MessageSource',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANBUS', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DECISION', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCALIZATION', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLANNING', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREDICTION', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMULATOR', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HWSYS', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUTING', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONITOR', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HMI', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATIVE_MAP', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GNSS', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTI_RADAR', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RACOBIT_RADAR', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ULTRASONIC_RADAR', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOBILEYE', index=17, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELPHI_ESR', index=18, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORYTELLING', index=19, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=308,
  serialized_end=618,
)
_sym_db.RegisterEnumDescriptor(_MONITORMESSAGEITEM_MESSAGESOURCE)

_MONITORMESSAGEITEM_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='apollo.common.monitor.MonitorMessageItem.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INFO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FATAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=620,
  serialized_end=672,
)
_sym_db.RegisterEnumDescriptor(_MONITORMESSAGEITEM_LOGLEVEL)


_MONITORMESSAGEITEM = _descriptor.Descriptor(
  name='MonitorMessageItem',
  full_name='apollo.common.monitor.MonitorMessageItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='apollo.common.monitor.MonitorMessageItem.source', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='apollo.common.monitor.MonitorMessageItem.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_level', full_name='apollo.common.monitor.MonitorMessageItem.log_level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONITORMESSAGEITEM_MESSAGESOURCE,
    _MONITORMESSAGEITEM_LOGLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=672,
)


_MONITORMESSAGE = _descriptor.Descriptor(
  name='MonitorMessage',
  full_name='apollo.common.monitor.MonitorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.common.monitor.MonitorMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='apollo.common.monitor.MonitorMessage.item', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=786,
)

_MONITORMESSAGEITEM.fields_by_name['source'].enum_type = _MONITORMESSAGEITEM_MESSAGESOURCE
_MONITORMESSAGEITEM.fields_by_name['log_level'].enum_type = _MONITORMESSAGEITEM_LOGLEVEL
_MONITORMESSAGEITEM_MESSAGESOURCE.containing_type = _MONITORMESSAGEITEM
_MONITORMESSAGEITEM_LOGLEVEL.containing_type = _MONITORMESSAGEITEM
_MONITORMESSAGE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_MONITORMESSAGE.fields_by_name['item'].message_type = _MONITORMESSAGEITEM
DESCRIPTOR.message_types_by_name['MonitorMessageItem'] = _MONITORMESSAGEITEM
DESCRIPTOR.message_types_by_name['MonitorMessage'] = _MONITORMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MonitorMessageItem = _reflection.GeneratedProtocolMessageType('MonitorMessageItem', (_message.Message,), {
  'DESCRIPTOR' : _MONITORMESSAGEITEM,
  '__module__' : 'modules.common.monitor_log.proto.monitor_log_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.monitor.MonitorMessageItem)
  })
_sym_db.RegisterMessage(MonitorMessageItem)

MonitorMessage = _reflection.GeneratedProtocolMessageType('MonitorMessage', (_message.Message,), {
  'DESCRIPTOR' : _MONITORMESSAGE,
  '__module__' : 'modules.common.monitor_log.proto.monitor_log_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.monitor.MonitorMessage)
  })
_sym_db.RegisterMessage(MonitorMessage)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/motion_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/motion_service.proto',
  package='apollo.perception',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-modules/perception/proto/motion_service.proto\x12\x11\x61pollo.perception\x1a!modules/common/proto/header.proto\"\xdc\x01\n\nMotionType\x12\x0b\n\x03m00\x18\x01 \x01(\x02\x12\x0b\n\x03m01\x18\x02 \x01(\x02\x12\x0b\n\x03m02\x18\x03 \x01(\x02\x12\x0b\n\x03m03\x18\x04 \x01(\x02\x12\x0b\n\x03m10\x18\x05 \x01(\x02\x12\x0b\n\x03m11\x18\x06 \x01(\x02\x12\x0b\n\x03m12\x18\x07 \x01(\x02\x12\x0b\n\x03m13\x18\x08 \x01(\x02\x12\x0b\n\x03m20\x18\t \x01(\x02\x12\x0b\n\x03m21\x18\n \x01(\x02\x12\x0b\n\x03m22\x18\x0b \x01(\x02\x12\x0b\n\x03m23\x18\x0c \x01(\x02\x12\x0b\n\x03m30\x18\r \x01(\x02\x12\x0b\n\x03m31\x18\x0e \x01(\x02\x12\x0b\n\x03m32\x18\x0f \x01(\x02\x12\x0b\n\x03m33\x18\x10 \x01(\x02\"\xe6\x01\n\rVehicleStatus\x12\x11\n\troll_rate\x18\x01 \x01(\x02\x12\x12\n\npitch_rate\x18\x02 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x03 \x01(\x02\x12\x10\n\x08velocity\x18\x04 \x01(\x02\x12\x12\n\nvelocity_x\x18\x05 \x01(\x02\x12\x12\n\nvelocity_y\x18\x06 \x01(\x02\x12\x12\n\nvelocity_z\x18\x07 \x01(\x02\x12\x0f\n\x07time_ts\x18\x08 \x01(\x01\x12\x0e\n\x06time_d\x18\t \x01(\x01\x12-\n\x06motion\x18\n \x01(\x0b\x32\x1d.apollo.perception.MotionType\"q\n\x0eMotion_Service\x12\x38\n\x0evehicle_status\x18\x01 \x03(\x0b\x32 .apollo.perception.VehicleStatus\x12%\n\x06header\x18\x02 \x01(\x0b\x32\x15.apollo.common.Header'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_MOTIONTYPE = _descriptor.Descriptor(
  name='MotionType',
  full_name='apollo.perception.MotionType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='m00', full_name='apollo.perception.MotionType.m00', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m01', full_name='apollo.perception.MotionType.m01', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m02', full_name='apollo.perception.MotionType.m02', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m03', full_name='apollo.perception.MotionType.m03', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m10', full_name='apollo.perception.MotionType.m10', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m11', full_name='apollo.perception.MotionType.m11', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m12', full_name='apollo.perception.MotionType.m12', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m13', full_name='apollo.perception.MotionType.m13', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m20', full_name='apollo.perception.MotionType.m20', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m21', full_name='apollo.perception.MotionType.m21', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m22', full_name='apollo.perception.MotionType.m22', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m23', full_name='apollo.perception.MotionType.m23', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m30', full_name='apollo.perception.MotionType.m30', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m31', full_name='apollo.perception.MotionType.m31', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m32', full_name='apollo.perception.MotionType.m32', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m33', full_name='apollo.perception.MotionType.m33', index=15,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=324,
)


_VEHICLESTATUS = _descriptor.Descriptor(
  name='VehicleStatus',
  full_name='apollo.perception.VehicleStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roll_rate', full_name='apollo.perception.VehicleStatus.roll_rate', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pitch_rate', full_name='apollo.perception.VehicleStatus.pitch_rate', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate', full_name='apollo.perception.VehicleStatus.yaw_rate', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='apollo.perception.VehicleStatus.velocity', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_x', full_name='apollo.perception.VehicleStatus.velocity_x', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_y', full_name='apollo.perception.VehicleStatus.velocity_y', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_z', full_name='apollo.perception.VehicleStatus.velocity_z', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_ts', full_name='apollo.perception.VehicleStatus.time_ts', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_d', full_name='apollo.perception.VehicleStatus.time_d', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motion', full_name='apollo.perception.VehicleStatus.motion', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=557,
)


_MOTION_SERVICE = _descriptor.Descriptor(
  name='Motion_Service',
  full_name='apollo.perception.Motion_Service',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_status', full_name='apollo.perception.Motion_Service.vehicle_status', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.perception.Motion_Service.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=559,
  serialized_end=672,
)

_VEHICLESTATUS.fields_by_name['motion'].message_type = _MOTIONTYPE
_MOTION_SERVICE.fields_by_name['vehicle_status'].message_type = _VEHICLESTATUS
_MOTION_SERVICE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
DESCRIPTOR.message_types_by_name['MotionType'] = _MOTIONTYPE
DESCRIPTOR.message_types_by_name['VehicleStatus'] = _VEHICLESTATUS
DESCRIPTOR.message_types_by_name['Motion_Service'] = _MOTION_SERVICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MotionType = _reflection.GeneratedProtocolMessageType('MotionType', (_message.Message,), {
  'DESCRIPTOR' : _MOTIONTYPE,
  '__module__' : 'modules.perception.proto.motion_service_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.MotionType)
  })
_sym_db.RegisterMessage(MotionType)

VehicleStatus = _reflection.GeneratedProtocolMessageType('VehicleStatus', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLESTATUS,
  '__module__' : 'modules.perception.proto.motion_service_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.VehicleStatus)
  })
_sym_db.RegisterMessage(VehicleStatus)

Motion_Service = _reflection.GeneratedProtocolMessageType('Motion_Service', (_message.Message,), {
  'DESCRIPTOR' : _MOTION_SERVICE,
  '__module__' : 'modules.perception.proto.motion_service_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.Motion_Service)
  })
_sym_db.RegisterMessage(Motion_Service)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/dreamview/proto/chart.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/dreamview/proto/chart.proto',
  package='apollo.dreamview',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#modules/dreamview/proto/chart.proto\x12\x10\x61pollo.dreamview\x1a#modules/common/proto/geometry.proto\"\xaa\x02\n\x07Options\x12\x1c\n\x0elegend_display\x18\x01 \x01(\x08:\x04true\x12)\n\x01x\x18\x02 \x01(\x0b\x32\x1e.apollo.dreamview.Options.Axis\x12)\n\x01y\x18\x03 \x01(\x0b\x32\x1e.apollo.dreamview.Options.Axis\x12\x14\n\x0c\x61spect_ratio\x18\x04 \x01(\x01\x12\"\n\x13sync_xy_window_size\x18\x05 \x01(\x08:\x05\x66\x61lse\x1aq\n\x04\x41xis\x12\x0b\n\x03min\x18\x01 \x01(\x01\x12\x0b\n\x03max\x18\x02 \x01(\x01\x12\x14\n\x0clabel_string\x18\x03 \x01(\t\x12\x13\n\x0bwindow_size\x18\x04 \x01(\x01\x12\x11\n\tstep_size\x18\x05 \x01(\x01\x12\x11\n\tmid_value\x18\x06 \x01(\x01\"\xd0\x01\n\x04Line\x12\r\n\x05label\x18\x01 \x01(\t\x12#\n\x14hide_label_in_legend\x18\x02 \x01(\x08:\x05\x66\x61lse\x12%\n\x05point\x18\x03 \x03(\x0b\x32\x16.apollo.common.Point2D\x12:\n\nproperties\x18\x04 \x03(\x0b\x32&.apollo.dreamview.Line.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd6\x01\n\x07Polygon\x12\r\n\x05label\x18\x01 \x01(\t\x12#\n\x14hide_label_in_legend\x18\x02 \x01(\x08:\x05\x66\x61lse\x12%\n\x05point\x18\x03 \x03(\x0b\x32\x16.apollo.common.Point2D\x12=\n\nproperties\x18\x04 \x03(\x0b\x32).apollo.dreamview.Polygon.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x03\x43\x61r\x12\r\n\x05label\x18\x01 \x01(\t\x12#\n\x14hide_label_in_legend\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01\x12\x0f\n\x07heading\x18\x05 \x01(\x01\x12\r\n\x05\x63olor\x18\x06 \x01(\t\"\xb8\x01\n\x05\x43hart\x12\r\n\x05title\x18\x01 \x01(\t\x12*\n\x07options\x18\x02 \x01(\x0b\x32\x19.apollo.dreamview.Options\x12$\n\x04line\x18\x03 \x03(\x0b\x32\x16.apollo.dreamview.Line\x12*\n\x07polygon\x18\x04 \x03(\x0b\x32\x19.apollo.dreamview.Polygon\x12\"\n\x03\x63\x61r\x18\x05 \x03(\x0b\x32\x15.apollo.dreamview.Car'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])




_OPTIONS_AXIS = _descriptor.Descriptor(
  name='Axis',
  full_name='apollo.dreamview.Options.Axis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='apollo.dreamview.Options.Axis.min', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='apollo.dreamview.Options.Axis.max', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label_string', full_name='apollo.dreamview.Options.Axis.label_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window_size', full_name='apollo.dreamview.Options.Axis.window_size', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step_size', full_name='apollo.dreamview.Options.Axis.step_size', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid_value', full_name='apollo.dreamview.Options.Axis.mid_value', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=393,
)

_OPTIONS = _descriptor.Descriptor(
  name='Options',
  full_name='apollo.dreamview.Options',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='legend_display', full_name='apollo.dreamview.Options.legend_display', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.dreamview.Options.x', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.dreamview.Options.y', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aspect_ratio', full_name='apollo.dreamview.Options.aspect_ratio', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sync_xy_window_size', full_name='apollo.dreamview.Options.sync_xy_window_size', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OPTIONS_AXIS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=393,
)


_LINE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='apollo.dreamview.Line.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.Line.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.Line.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=604,
)

_LINE = _descriptor.Descriptor(
  name='Line',
  full_name='apollo.dreamview.Line',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='apollo.dreamview.Line.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_label_in_legend', full_name='apollo.dreamview.Line.hide_label_in_legend', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point', full_name='apollo.dreamview.Line.point', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='apollo.dreamview.Line.properties', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LINE_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=604,
)


_POLYGON_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='apollo.dreamview.Polygon.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.Polygon.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.Polygon.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=604,
)

_POLYGON = _descriptor.Descriptor(
  name='Polygon',
  full_name='apollo.dreamview.Polygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='apollo.dreamview.Polygon.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_label_in_legend', full_name='apollo.dreamview.Polygon.hide_label_in_legend', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point', full_name='apollo.dreamview.Polygon.point', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='apollo.dreamview.Polygon.properties', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_POLYGON_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=821,
)


_CAR = _descriptor.Descriptor(
  name='Car',
  full_name='apollo.dreamview.Car',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='apollo.dreamview.Car.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_label_in_legend', full_name='apollo.dreamview.Car.hide_label_in_legend', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.dreamview.Car.x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.dreamview.Car.y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.dreamview.Car.heading', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='apollo.dreamview.Car.color', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=934,
)


_CHART = _descriptor.Descriptor(
  name='Chart',
  full_name='apollo.dreamview.Chart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='apollo.dreamview.Chart.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='apollo.dreamview.Chart.options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line', full_name='apollo.dreamview.Chart.line', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='apollo.dreamview.Chart.polygon', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='car', full_name='apollo.dreamview.Chart.car', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=1121,
)

_OPTIONS_AXIS.containing_type = _OPTIONS
_OPTIONS.fields_by_name['x'].message_type = _OPTIONS_AXIS
_OPTIONS.fields_by_name['y'].message_type = _OPTIONS_AXIS
_LINE_PROPERTIESENTRY.containing_type = _LINE
_LINE.fields_by_name['point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_LINE.fields_by_name['properties'].message_type = _LINE_PROPERTIESENTRY
_POLYGON_PROPERTIESENTRY.containing_type = _POLYGON
_POLYGON.fields_by_name['point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_POLYGON.fields_by_name['properties'].message_type = _POLYGON_PROPERTIESENTRY
_CHART.fields_by_name['options'].message_type = _OPTIONS
_CHART.fields_by_name['line'].message_type = _LINE
_CHART.fields_by_name['polygon'].message_type = _POLYGON
_CHART.fields_by_name['car'].message_type = _CAR
DESCRIPTOR.message_types_by_name['Options'] = _OPTIONS
DESCRIPTOR.message_types_by_name['Line'] = _LINE
DESCRIPTOR.message_types_by_name['Polygon'] = _POLYGON
DESCRIPTOR.message_types_by_name['Car'] = _CAR
DESCRIPTOR.message_types_by_name['Chart'] = _CHART
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Options = _reflection.GeneratedProtocolMessageType('Options', (_message.Message,), {

  'Axis' : _reflection.GeneratedProtocolMessageType('Axis', (_message.Message,), {
    'DESCRIPTOR' : _OPTIONS_AXIS,
    '__module__' : 'modules.dreamview.proto.chart_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.Options.Axis)
    })
  ,
  'DESCRIPTOR' : _OPTIONS,
  '__module__' : 'modules.dreamview.proto.chart_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Options)
  })
_sym_db.RegisterMessage(Options)
_sym_db.RegisterMessage(Options.Axis)

Line = _reflection.GeneratedProtocolMessageType('Line', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _LINE_PROPERTIESENTRY,
    '__module__' : 'modules.dreamview.proto.chart_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.Line.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _LINE,
  '__module__' : 'modules.dreamview.proto.chart_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Line)
  })
_sym_db.RegisterMessage(Line)
_sym_db.RegisterMessage(Line.PropertiesEntry)

Polygon = _reflection.GeneratedProtocolMessageType('Polygon', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _POLYGON_PROPERTIESENTRY,
    '__module__' : 'modules.dreamview.proto.chart_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.Polygon.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _POLYGON,
  '__module__' : 'modules.dreamview.proto.chart_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Polygon)
  })
_sym_db.RegisterMessage(Polygon)
_sym_db.RegisterMessage(Polygon.PropertiesEntry)

Car = _reflection.GeneratedProtocolMessageType('Car', (_message.Message,), {
  'DESCRIPTOR' : _CAR,
  '__module__' : 'modules.dreamview.proto.chart_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Car)
  })
_sym_db.RegisterMessage(Car)

Chart = _reflection.GeneratedProtocolMessageType('Chart', (_message.Message,), {
  'DESCRIPTOR' : _CHART,
  '__module__' : 'modules.dreamview.proto.chart_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Chart)
  })
_sym_db.RegisterMessage(Chart)


_LINE_PROPERTIESENTRY._options = None
_POLYGON_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)
